import { CodeBuildClient } from "./CodeBuildClient";
import { BatchDeleteBuildsInput } from "./types/BatchDeleteBuildsInput";
import { BatchDeleteBuildsOutput } from "./types/BatchDeleteBuildsOutput";
import { BatchGetBuildsInput } from "./types/BatchGetBuildsInput";
import { BatchGetBuildsOutput } from "./types/BatchGetBuildsOutput";
import { BatchGetProjectsInput } from "./types/BatchGetProjectsInput";
import { BatchGetProjectsOutput } from "./types/BatchGetProjectsOutput";
import { CreateProjectInput } from "./types/CreateProjectInput";
import { CreateProjectOutput } from "./types/CreateProjectOutput";
import { CreateWebhookInput } from "./types/CreateWebhookInput";
import { CreateWebhookOutput } from "./types/CreateWebhookOutput";
import { DeleteProjectInput } from "./types/DeleteProjectInput";
import { DeleteProjectOutput } from "./types/DeleteProjectOutput";
import { DeleteSourceCredentialsInput } from "./types/DeleteSourceCredentialsInput";
import { DeleteSourceCredentialsOutput } from "./types/DeleteSourceCredentialsOutput";
import { DeleteWebhookInput } from "./types/DeleteWebhookInput";
import { DeleteWebhookOutput } from "./types/DeleteWebhookOutput";
import { ImportSourceCredentialsInput } from "./types/ImportSourceCredentialsInput";
import { ImportSourceCredentialsOutput } from "./types/ImportSourceCredentialsOutput";
import { InvalidateProjectCacheInput } from "./types/InvalidateProjectCacheInput";
import { InvalidateProjectCacheOutput } from "./types/InvalidateProjectCacheOutput";
import { ListBuildsForProjectInput } from "./types/ListBuildsForProjectInput";
import { ListBuildsForProjectOutput } from "./types/ListBuildsForProjectOutput";
import { ListBuildsInput } from "./types/ListBuildsInput";
import { ListBuildsOutput } from "./types/ListBuildsOutput";
import { ListCuratedEnvironmentImagesInput } from "./types/ListCuratedEnvironmentImagesInput";
import { ListCuratedEnvironmentImagesOutput } from "./types/ListCuratedEnvironmentImagesOutput";
import { ListProjectsInput } from "./types/ListProjectsInput";
import { ListProjectsOutput } from "./types/ListProjectsOutput";
import { ListSourceCredentialsInput } from "./types/ListSourceCredentialsInput";
import { ListSourceCredentialsOutput } from "./types/ListSourceCredentialsOutput";
import { StartBuildInput } from "./types/StartBuildInput";
import { StartBuildOutput } from "./types/StartBuildOutput";
import { StopBuildInput } from "./types/StopBuildInput";
import { StopBuildOutput } from "./types/StopBuildOutput";
import { UpdateProjectInput } from "./types/UpdateProjectInput";
import { UpdateProjectOutput } from "./types/UpdateProjectOutput";
import { UpdateWebhookInput } from "./types/UpdateWebhookInput";
import { UpdateWebhookOutput } from "./types/UpdateWebhookOutput";
export declare class CodeBuild extends CodeBuildClient {
    /**
     * <p>Deletes one or more builds.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    batchDeleteBuilds(args: BatchDeleteBuildsInput): Promise<BatchDeleteBuildsOutput>;
    batchDeleteBuilds(args: BatchDeleteBuildsInput, cb: (err: any, data?: BatchDeleteBuildsOutput) => void): void;
    /**
     * <p>Gets information about builds.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    batchGetBuilds(args: BatchGetBuildsInput): Promise<BatchGetBuildsOutput>;
    batchGetBuilds(args: BatchGetBuildsInput, cb: (err: any, data?: BatchGetBuildsOutput) => void): void;
    /**
     * <p>Gets information about build projects.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    batchGetProjects(args: BatchGetProjectsInput): Promise<BatchGetProjectsOutput>;
    batchGetProjects(args: BatchGetProjectsInput, cb: (err: any, data?: BatchGetProjectsOutput) => void): void;
    /**
     * <p>Creates a build project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceAlreadyExistsException} <p>The specified AWS resource cannot be created, because an AWS resource with the same settings already exists.</p>
     *   - {AccountLimitExceededException} <p>An AWS service limit was exceeded for the calling AWS account.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createProject(args: CreateProjectInput): Promise<CreateProjectOutput>;
    createProject(args: CreateProjectInput, cb: (err: any, data?: CreateProjectOutput) => void): void;
    /**
     * <p>For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables AWS CodeBuild to start rebuilding the source code every time a code change is pushed to the repository.</p> <important> <p>If you enable webhooks for an AWS CodeBuild project, and the project is used as a build step in AWS CodePipeline, then two identical builds are created for each commit. One build is triggered through webhooks, and one through AWS CodePipeline. Because billing is on a per-build basis, you are billed for both builds. Therefore, if you are using AWS CodePipeline, we recommend that you disable webhooks in AWS CodeBuild. In the AWS CodeBuild console, clear the Webhook box. For more information, see step 5 in <a href="https://docs.aws.amazon.com/codebuild/latest/userguide/change-project.html#change-project-console">Change a Build Project's Settings</a>.</p> </important>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {OAuthProviderException} <p>There was a problem with the underlying OAuth provider.</p>
     *   - {ResourceAlreadyExistsException} <p>The specified AWS resource cannot be created, because an AWS resource with the same settings already exists.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createWebhook(args: CreateWebhookInput): Promise<CreateWebhookOutput>;
    createWebhook(args: CreateWebhookInput, cb: (err: any, data?: CreateWebhookOutput) => void): void;
    /**
     * <p>Deletes a build project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteProject(args: DeleteProjectInput): Promise<DeleteProjectOutput>;
    deleteProject(args: DeleteProjectInput, cb: (err: any, data?: DeleteProjectOutput) => void): void;
    /**
     * <p> Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteSourceCredentials(args: DeleteSourceCredentialsInput): Promise<DeleteSourceCredentialsOutput>;
    deleteSourceCredentials(args: DeleteSourceCredentialsInput, cb: (err: any, data?: DeleteSourceCredentialsOutput) => void): void;
    /**
     * <p>For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops AWS CodeBuild from rebuilding the source code every time a code change is pushed to the repository.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {OAuthProviderException} <p>There was a problem with the underlying OAuth provider.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteWebhook(args: DeleteWebhookInput): Promise<DeleteWebhookOutput>;
    deleteWebhook(args: DeleteWebhookInput, cb: (err: any, data?: DeleteWebhookOutput) => void): void;
    /**
     * <p> Imports the source repository credentials for an AWS CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, or Bitbucket repository. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {AccountLimitExceededException} <p>An AWS service limit was exceeded for the calling AWS account.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    importSourceCredentials(args: ImportSourceCredentialsInput): Promise<ImportSourceCredentialsOutput>;
    importSourceCredentials(args: ImportSourceCredentialsInput, cb: (err: any, data?: ImportSourceCredentialsOutput) => void): void;
    /**
     * <p>Resets the cache for a project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    invalidateProjectCache(args: InvalidateProjectCacheInput): Promise<InvalidateProjectCacheOutput>;
    invalidateProjectCache(args: InvalidateProjectCacheInput, cb: (err: any, data?: InvalidateProjectCacheOutput) => void): void;
    /**
     * <p>Gets a list of build IDs, with each build ID representing a single build.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listBuilds(args: ListBuildsInput): Promise<ListBuildsOutput>;
    listBuilds(args: ListBuildsInput, cb: (err: any, data?: ListBuildsOutput) => void): void;
    /**
     * <p>Gets a list of build IDs for the specified build project, with each build ID representing a single build.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listBuildsForProject(args: ListBuildsForProjectInput): Promise<ListBuildsForProjectOutput>;
    listBuildsForProject(args: ListBuildsForProjectInput, cb: (err: any, data?: ListBuildsForProjectOutput) => void): void;
    /**
     * <p>Gets information about Docker images that are managed by AWS CodeBuild.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listCuratedEnvironmentImages(args: ListCuratedEnvironmentImagesInput): Promise<ListCuratedEnvironmentImagesOutput>;
    listCuratedEnvironmentImages(args: ListCuratedEnvironmentImagesInput, cb: (err: any, data?: ListCuratedEnvironmentImagesOutput) => void): void;
    /**
     * <p>Gets a list of build project names, with each build project name representing a single build project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listProjects(args: ListProjectsInput): Promise<ListProjectsOutput>;
    listProjects(args: ListProjectsInput, cb: (err: any, data?: ListProjectsOutput) => void): void;
    /**
     * <p> Returns a list of <code>SourceCredentialsInfo</code> objects. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listSourceCredentials(args: ListSourceCredentialsInput): Promise<ListSourceCredentialsOutput>;
    listSourceCredentials(args: ListSourceCredentialsInput, cb: (err: any, data?: ListSourceCredentialsOutput) => void): void;
    /**
     * <p>Starts running a build.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {AccountLimitExceededException} <p>An AWS service limit was exceeded for the calling AWS account.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    startBuild(args: StartBuildInput): Promise<StartBuildOutput>;
    startBuild(args: StartBuildInput, cb: (err: any, data?: StartBuildOutput) => void): void;
    /**
     * <p>Attempts to stop running a build.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    stopBuild(args: StopBuildInput): Promise<StopBuildOutput>;
    stopBuild(args: StopBuildInput, cb: (err: any, data?: StopBuildOutput) => void): void;
    /**
     * <p>Changes the settings of a build project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateProject(args: UpdateProjectInput): Promise<UpdateProjectOutput>;
    updateProject(args: UpdateProjectInput, cb: (err: any, data?: UpdateProjectOutput) => void): void;
    /**
     * <p> Updates the webhook associated with an AWS CodeBuild build project. </p> <note> <p> If you use Bitbucket for your repository, <code>rotateSecret</code> is ignored. </p> </note>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidInputException} <p>The input value that was provided is not valid.</p>
     *   - {ResourceNotFoundException} <p>The specified AWS resource cannot be found.</p>
     *   - {OAuthProviderException} <p>There was a problem with the underlying OAuth provider.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateWebhook(args: UpdateWebhookInput): Promise<UpdateWebhookOutput>;
    updateWebhook(args: UpdateWebhookInput, cb: (err: any, data?: UpdateWebhookOutput) => void): void;
}
